@@ -4,7 +4,10 @@ import importlib
 from future.builtins import str
 import logging_helper
 from future.utils import iteritems
-from collections import MutableMapping
+try:
+    from collections.abc import MutableMapping
+except ImportError:
+    from collections import MutableMapping
 from ..config.constants import HandlerConstant
 from ..config.intercept_handlers import Handlers
 
