@@ -99,7 +99,9 @@ class InterceptUpdaters(MutableMapping):
 
             # Filter the list to drop init & python compiled files
             module_dir_list = filter_list(module_dir_list,
-                                          [u'__init__', u'.pyc'],
+                                          [u'__init__',
+                                           u'.pyc',
+                                           u'__pycache__'],
                                           exclude=True)
 
             # Filter the list to get only directories
@@ -120,7 +122,7 @@ class InterceptUpdaters(MutableMapping):
             # Register updaters in sub-dirs
             for path in filtered_module_dir_list:
                 new_dir = path.split(os.sep).pop()
-                key = new_dir if not folder else u'{key}.{dir}'.format(key=key,
+                key = new_dir if not folder else u'{key}.{dir}'.format(key=folder,
                                                                        dir=new_dir)
                 self.__discover_updaters(dir_path=os.path.join(dir_path, path),
                                          updater_root=updater_root,
